
# This file was generated by 'versioneer.py' (0.13+dev) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

version_version = '0.1.0a5'
version_full = 'bb11134903bc83dc91d25ffde6f01aec3b9b453c'
def get_versions(default={}, verbose=False):
    return {'version': version_version, 'full': version_full}

